#
# spec file for package termit
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           termit
Version:        3.1
Release:        bp156.2.7
Summary:        Vte-based Terminal Emulator
License:        GPL-3.0-or-later
Group:          System/X11/Terminals
URL:            https://github.com/nonstop/termit/wiki
Source:         https://github.com/nonstop/termit/archive/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 2.6.0
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  gettext-devel
BuildRequires:  libstdc++-devel
BuildRequires:  lua-devel >= 5.1
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(vte-2.91) >= 0.60.0
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif

%description
termit is a terminal emulator based on the vte library. It includes tabs,
bookmarks, and the ability to switch encodings.

%prep
%setup -q -n %{name}-%{name}-%{version}

%build
%cmake -DDEBUG=false -DCMAKE_C_FLAGS="$(pkg-config --cflags-only-I vte-2.91)"
%cmake_build

%install
%cmake_install
rm -rf "%{buildroot}%{_datadir}/doc"
rm -rf "%{buildroot}%{_prefix}/src"
%if 0%{?suse_version}
%suse_update_desktop_file -r %{name} System TerminalEmulator
%endif

%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc ChangeLog TODO
%doc doc/README
%doc doc/rc.lua.example
%doc doc/lua_api.txt
%dir %{_sysconfdir}/xdg/%{name}
%{_datadir}/locale/**/LC_MESSAGES/termit.mo
%config %{_sysconfdir}/xdg/%{name}/colormaps.lua
%config %{_sysconfdir}/xdg/%{name}/utils.lua
%config %{_sysconfdir}/xdg/%{name}/rc.lua
%{_bindir}/%{name}
%{_datadir}/metainfo/termit.metainfo.xml
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Mon Jan 11 2021 Avindra Goolcharan <avindra@opensuse.org>
- Fix build (link vte)
* Mon Nov 30 2020 Avindra Goolcharan <avindra@opensuse.org>
- Update to 3.1.0
  * completely switched to Lua 5.3
  * disabled annoying menubar on F10
  * new options: scrollOnKeystroke, scrollOnOutput
  * fixed GTK deprecations
  * fixed several bugs
  * replaced appdata with modern metainfo
- ran spec-cleaner
* Wed Feb  7 2018 avindra@opensuse.org
- remove libtool build dependency (unneeded)
* Sat Oct 28 2017 aavindraa@gmail.com
- update to 3.0.0
  + added AppData file
  + license changed to GPLv3.0+
  + added 'apply to all tabs' in preferences dialog
  + new options: cursorBlinkMode, cursorShape startMaximized,
    hideTitlebarWhenMaximized
  + wordChars replaced with wordCharExceptions
  + removed options: imageFile, transparency, visibleBell
  + Require libvte>0.29 and Gtk-3.
- Lint .spec file
- Drop xz build requirement
* Thu Jan  7 2016 sweet_f_a@gmx.de
- update to 2.10.1:
  * Fixed error with conflicting libvte/Gtk versions
  * Fixed ebuild (by Ilya Mochalov).
  * Suppress "invalid option" for -e.
  * Fixed missing link to math library
  * Miminum required version for Gtk-2 changed to 2.24.
  * Miminum required version for libvte changed to 0.28.
  * Rebuild po-files due to source changes.
* Thu Nov  6 2014 sweet_f_a@gmx.de
- build with vte2/gtk2 because API seems to be more stable than
  vte/gtk3, (gtk3 build failed for openSUSE >= 13.2)
* Wed Apr 23 2014 sweet_f_a@gmx.de
- update to 2.10.0:
  * version 2.8.1
    fixed bug in currentTabIndex
  * version 2.9.0
    new Lua functions:
    setColormap
    added support for system-wide rc.lua
    added support for using modules in rc.lua
    added several predefined colormaps
  * version 2.9.1
    fixed setEncoding in termit.utils module
    fixed possible zombie process
  * version 2.9.2
    fix build with --as-needed linker flags enabled (patch by Artur Frysiak)
    Meta, Super and Hyper in keybindings (patch by Artur Frysiak)
    project language set to C
    new Lua functions:
    feed feedChild
    fixed some compilation issues when using Gtk+3
    added Japanese translation (by Nobuhiro Iwamatsu)
  * version 2.9.3
    fixed installing as non-root
    added Spanish translation (by Martintxo)
    added German translation (by Dennis Ploeger)
    updated Hungarian translation (by Peter Polonkai)
    apply foreground color for bold fonts
    added several WM-specific commandline options: --name, --class, --role
  * version 2.9.4
    fix hyphen-used-as-minus-sign in manpage (by Thomas Koch)
    new options:
    hideTabbar (by Anurag Priyam)
    new Lua functions:
    toggleTabbar
    added Polish translation (by Miś Uszatek)
    added Danish translation
    added support for Lua 5.2
    fixed docs
  * version 2.9.5
    fixed bug with hideTabbar and hideSingleTab
    tabs indexes start with 1 (Lua-indexing)
    fixed desktop file
    added Swedish translation (by Tomas Fasth)
  * version 2.9.6
    fixed handling geometry setting
    added support to choose libraries while configuring termit build
    scrollable tabs in tabbar
    new options:
    tabPos - set tabbar position
  * version 2.10.0
    fixed compilation for OpenBSD
    prevent building termit with incompatible Gtk and Vte versions
    "exec" commandline option now works nearly like in xterm
    new options:
    showBorder - show notebook's borders
- cleanup spec file
* Wed May 25 2011 carloscs@keysoft.pt
- update to 2.8.0
  search in vte buffer (only for vte >= 0.26)
  new Lua functions
  forEachRow
  forEachVisibleRow
  findDlg findNext findPrev
  new options
  backspaceBinding
  deleteBinding
  setStatusbar
  extra warnings when compiling in DEBUG mode
  fixed docs
* Tue Mar 29 2011 carloscs@keysoft.pt
- update to 2.7.1
  display proper encoding when switching pages
* Fri Feb 25 2011 carloscs@keysoft.pt
- update to 2.7.0
  refactored reading table from Lua
  fixed working with sessions
  new options:
  imageFile - path to image to be set on the background
  colormap - instead of setColormap
  matches - instead of setMatches
  tabs - opened by default tabs
  changed default binding for 'closeTab' from 'Ctrl-w' to 'CtrlShift-w'
  cleanup
  fixed docs
* Sat Nov  6 2010 carloscs@keysoft.pt
- update to 2.6.0
  fixed -e option: read configs first only then execute
  accelerators for user menus
  new Lua functions
  setTabTitleDlg
  loadSessionDlg
  saveSessionDlg
  preferencesDlg
  quit
  cleanup
  fixed docs
  removed support for deprecated:
  use rc.lua instead of init.lua
  in openTab use title instead of name
  and workingDir instead of working_dir
  action in menuitem must be lua-function
* Wed Apr 21 2010 pascal.bleser@opensuse.org
- update to 2.5.0:
  * Lua functions: 'selection' and 'currentTab' have been added
  * global variable 'tabs' has been added: read-only access to tabs' properties
  * a bug causing a hidden menu to appear after reconfiguring has been fixed
  * documentation has been fixed
  * there are several changes in the Lua API
- changes from 2.4.0:
  * support for changing color maps
* Mon Nov 23 2009 pascal.bleser@opensuse.org
- update to 2.3.0:
  * adds the options audibleBell and visibleBell
  * adds support for urgency hint
  * custom actions on different matches (initial support)
- changes from 2.2.0:
  * bugs were fixed
  * mixed modifiers (such as AltCtrl or AltShift) are supported
  * new Lua functions were added:
    + setTabForegroundColor
    + setTabBackgroundColor
    + bindMouse
    + toggleMenubar
    + setWindowTitle
    + currentTabIndex
    + getTabTitle
    + getWindowTitle
  * new options were added
    + per-tab foreground/background colors
    + fillTabbar
    + hideMenubar
    + changeTitle
- changes from 2.1.1:
  * fixes a bug with black default font color
  * the man-page and init.lua.example were fixed
* Thu Nov  6 2008 guru@unixtech.be
- update to 2.1
* Tue Sep  9 2008 guru@unixtech.be
- update to 1.3.5:
  * a Korean translation was added
  * a bug with showing and hiding the scrollbar was fixed
* Wed Aug 27 2008 guru@unixtech.be
- update to 1.3.4:
  * fixed bugs with loading keybindings
  * updated Hungarian translation
* Sun Jun 29 2008 guru@unixtech.be
- new upstream version:
  * support was added for keyboard policy for shortcuts
* Tue Jun 10 2008 guru@unixtech.be
- new upstream version:
  fixed loading default options when no configuration file was found
* Sun May 25 2008 guru@unixtech.be
- new upstream version:
  * the show_scrollbar option was added in the popup menu and termit.cfg
  * the shell_cmd variable was split into shell and shell_cmd
  * fixes were made for a bug with uninitialized GError,
  - -usage output,
  statusbar encoding when loading session,
  and compilation warnings
  * the documentation was updated
* Wed Apr  9 2008 guru@unixtech.be
- new upstream version
* Thu Feb  7 2008 guru@unixtech.be
- monospace patch merged by upstream
- new upstream version
* Tue Jan 22 2008 guru@unixtech.be
- new upstream version
* Mon Dec 24 2007 guru@unixtech.be
- moved to openSUSE Build Service
- moved doc files from /usr/share/doc/termit to /usr/share/doc/packages/termit
- build changed to cmake
- new upstream version
* Mon Sep 24 2007 guru@unixtech.be
- new upstream version
* Thu Sep  6 2007 guru@unixtech.be
- moved to Packman
- new upstream version
* Mon Jul 16 2007 guru@unixtech.be
- new package
